#!/bin/bash
#Automatically Created by buildpkg 1.7.0
#Maintainer: Pedro Pinto (pnboy~AT~pinguix.com)
#url: http://go-oo.org/

######Begin Redundant Code######################################
check_for_root() {
	if [ "$UID" != "0" ]; then
		echo "You need to be root"
		exit 1
	fi
}

clean_dirs () {
        for COMPLETED in src pkg; do
                if [ -e $COMPLETED ]; then
                        rm -rf $COMPLETED
                fi
        done
}

clean_old_builds () {
	for COMPLETED in $package.{txz,tgz,md5,dep}; do
		if [ "$KEEPDEPFILE" = "1" ] && [ $COMPLETED = $package.dep ]; then
			continue
		elif [ -e $COMPLETED ]; then
			rm -rf $COMPLETED
		fi
	done
	clean_dirs
}

set_pre_permissions() {
	cd $startdir/src
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
}


check_for_menu_compliance() {
	if [ -d "$startdir/pkg/usr/share/applications" ]; then
		cd $startdir/pkg/usr/share/applications
		for desktop in *.desktop; do
			Icon=$(grep -e "^Icon=" $desktop | sed 's/Icon=//')
			if [[ "$Icon" ]]; then
				if [ ! "$Icon" == "${Icon%.*}" ]; then
					sed '/Icon/s/\..*$//' -i $desktop
					Icon=$(grep -e "^Icon=" $desktop | sed 's/Icon=//')
				fi
				if [ -d "$startdir/pkg/usr/share/pixmaps" ]; then
					cd $startdir/pkg/usr/share/pixmaps
					for pixmaps in *; do
						[ -d $pixmaps ] && continue
						[ ! "${pixmaps##*.}" == "png" -a ! "${pixmaps##*.}" == "svg" ] && continue
				 		if [ "${pixmaps%.*}" == "$Icon" ]; then
				 			DIR=$(file $pixmaps | awk -F, '{print $2}' | sed 's/ //g')
							[ o"$DIR" == "o" ] && DIR="scalable"
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $pixmaps $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							if [[ ! "$(ls $startdir/pkg/usr/share/pixmaps)" ]]; then
								rm -rf $startdir/pkg/usr/share/pixmaps
							fi
						fi
					done
				fi
				if [ -d "$startdir/pkg/usr/share/icons" ]; then
					cd $startdir/pkg/usr/share/icons
					for icons in *; do
				 		if [ "${icons%.*}" == "$Icon" ]; then
							[ ! "${pixmaps##*.}" == "png" -a ! "${pixmaps##*.}" == "svg" ] && continue
				 			DIR=$(file $icons | awk -F, '{print $2}' | sed 's/ //g')
							[ o"$DIR" == "o" ] && DIR="scalable"
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $icons $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
						fi
					done
				fi
			fi
		done
	fi
}


gzip_man_and_info_pages() {
	for DOCS in man info; do
		if [ -d "$startdir/pkg/usr/share/$DOCS" ]; then
			mv $startdir/pkg/usr/share/$DOCS $startdir/pkg/usr/$DOCS
			if [[ ! "$(ls $startdir/pkg/usr/share)" ]]; then
				rm -rf $startdir/pkg/usr/share
			fi
		fi
		if [ -d "$startdir/pkg/usr/$DOCS" ]; then
			# I've never seen symlinks in info pages....
			if [ "$DOCS" == "man" ]; then
				(cd $startdir/pkg/usr/$DOCS
				for manpagedir in $(find . -type d -name "man*" 2> /dev/null) ; do
					( cd $manpagedir
					for eachpage in $( find . -type l -maxdepth 1 2> /dev/null) ; do
						ln -s $( readlink $eachpage ).gz $eachpage.gz
						rm $eachpage
					done )
				done)
			fi
			find $startdir/pkg/usr/$DOCS -type f -exec gzip -9 '{}' \;
		fi
	done
}

set_post_permissions() {
	for DIRS in usr/share/icons usr/doc; do
		if [ -d "$startdir/pkg/$DIRS" ]; then
			if [ "$DIRS" == "usr/doc" ]; then
				find $startdir/pkg/$DIRS -type f -exec chmod 644 {} \;
				find $startdir/pkg/$DIRS -type d -exec chmod 755 {} \;
			fi
		fi
		[ -d $startdir/pkg/$DIRS ] && chown root:root -R $startdir/pkg/$DIRS
	done
	[ -d $startdir/pkg/usr/bin ] && find $startdir/pkg/usr/bin -user root -group bin -exec chown root:root {} \;
}

copy_build_script() {
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver/
	cp $startdir/build-$pkgname.sh $startdir/pkg/usr/src/$pkgname-$pkgver/build-$pkgname.sh
	[ -f $startdir/ZENBUILD ] && cp $startdir/ZENBUILD $startdir/pkg/usr/src/$pkgname-$pkgver/ZENBUILD
}

create_package() {
	ls -lR $startdir/pkg
	cd $startdir/pkg
	/sbin/makepkg -l y -c n $startdir/$package.$PKGEXTENSION
	cd $startdir
	md5sum $package.$PKGEXTENSION > $startdir/$package.md5
}

strip_binaries() {
	cd $startdir/pkg
	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
}
#########End Redundant Code#####################################
#########Begin Non Redundant Code##############################

prepare_directory() {
	mkdir $startdir/src
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver
	for SOURCES in ${source[@]}; do
		protocol=$(echo $SOURCES | sed 's|:.*||')
	        file=$(basename $SOURCES | awk -F= '{print $NF}')
		if [ ! -f "$file" ]; then
			if [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
				echo -e "\nDownloading $(basename $SOURCES)\n"
        	                wget $SOURCES -O $file
				if [ ! "$?" == "0" ]; then
					echo "Download failed"
					exit 2
				fi 
			else
				echo "$SOURCES does not appear to be a url nor is it in the directory"
				exit 2
			fi
		fi
		cp -R $file $startdir/src
		if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
			cp -R $startdir/$(basename $SOURCES) $startdir/pkg/usr/src/$pkgname-$pkgver/
		fi
		if [ "${SOURCES##*.}" == "desktop" ]; then
			[[ "$(grep -e "^Categories=[a-zA-Z]*;" $(basename $SOURCES))" ]] && install -D $startdir/$(basename $SOURCES) /home/packages/openoffice/pkg/usr/share/applications/$(basename $SOURCES)
		fi
	done
}

build() {
	cd $startdir/src/
	for file in *.rpm; do
		if ! `echo ${_toExtra[@]} | grep "${file}" 1>/dev/null 2>&1`
		then
			echo $file
			/usr/bin/rpm2targz $file
			tar xf $(basename "$file" .rpm).tar.gz -C $startdir/pkg
		fi
	done
	#for i in $startdir/src/*.rpm; do
	#	rpm2cpio $i | cpio -id --quiet
	#	cp -r $startdir/src/tmp/* $startdir/pkg
	#	rm -rf $startdir/src/tmp/*
	#done
	STRIMVER=${pkgver%.*}
	mkdir -p $startdir/pkg/usr/lib/openoffice.org${pkgver%.*}
	cd $startdir/pkg/opt
	mv */* $startdir/pkg/usr/lib/openoffice.org${pkgver%.*}
	rm -rf $startdir/pkg/usr/lib/openoffice.org${pkgver%.*}/basis${pkgver%.*}/program/python-core*
	cd $startdir/pkg/usr/lib/openoffice.org${pkgver%.*}
	rm basis-link
	ln -s basis${pkgver%.*} basis-link
	mkdir -p $startdir/pkg/usr/share/applications/
	cd $startdir/pkg/usr/share/applications/
	for APPS in base calc draw impress math writer ; do
        	ln -sf ../../lib/openoffice.org${pkgver%.*}/share/xdg/$APPS.desktop openoffice.org-${pkgver%.*}-$APPS.desktop
	done
	STRIMVER=${STRIMVER%.*}
	cd $startdir/pkg/usr/lib/openoffice.org${pkgver%.*}/share/xdg/
	sed -i -e "s|openoffice.org$STRIMVER -calc %U|oocalc|g" calc.desktop
	sed -i -e "s|openoffice.org$STRIMVER -draw %U|oodraw|g" draw.desktop
	sed -i -e "s|openoffice.org$STRIMVER -impress %U|ooimpress|g" impress.desktop
	sed -i -e "s|openoffice.org$STRIMVER -writer %U|oowriter|g" writer.desktop
	mkdir -p $startdir/pkg/usr/bin/
	cd $startdir/pkg/usr/bin/
	ln -sf ../lib/openoffice.org${pkgver%.*}/program/soffice soffice
	ln -sf ../lib/openoffice.org${pkgver%.*}/program/unopkg unopkg
	mkdir -p $PKG/usr/share/icons/hicolor/48x48/mimetypes/
	install -d -m755 $startdir/pkg/usr/share/icons/hicolor/48x48/apps/
	install -v -m644 $startdir/pkg/usr/share/icons/hicolor/48x48/mimetypes/openofficeorg3-oasis-{text,presentation,database,drawing,spreadsheet,formula}.png $startdir/pkg/usr/share/icons/hicolor/48x48/apps/

	sed -i "s|opt/openoffice.org3|usr/lib/openoffice.org${pkgver%.*}|g" $startdir/pkg/usr/bin/openoffice.org3
	sed -i "s|opt/openoffice.org3|usr/lib/openoffice.org${pkgver%.*}|g" $startdir/pkg/usr/bin/openoffice.org3-printeradmin

	# Make symlinks to the binaries
	for APPS in base calc draw math writer padmin impress ; do
	cat << EoF > $startdir/pkg/usr/bin/oo$APPS
#!/bin/bash
exec /usr/lib/openoffice.org${pkgver%.*}/program/s$APPS "\$@"
EoF
	chmod +x $startdir/pkg/usr/bin/oo$APPS
	done
	cp $startdir/src/openabout_go-oo.bmp $startdir/pkg/usr/lib/openoffice.org${pkgver%.*}/program/openabout_go-oo.bmp
	cp $startdir/src/openintro_go-oo.bmp $startdir/pkg/usr/lib/openoffice.org${pkgver%.*}/program/openintro_go-oo.bmp
	rm -rvf $startdir/pkg/usr/share/applications/openoffice.org3*.desktop
	rm -rfv $startdir/pkg/opt
	sed -i -e "s|<value>auto</value>|<value>tango</value>|g" $startdir/pkg/usr/lib/openoffice.org${pkgver%.*}/basis${pkgver%.*}/share/registry/schema/org/openoffice/Office/Common.xcs
	package2=$pkgname-extra-$pkgver-$arch-$zenver.$pkgrel
        mkdir -p $startdir/pkg2/install/
        cat << EOF > $startdir/pkg2/install/slack-desc
$pkgname-extra: $pkgname-extra (Extra open-office files)
$pkgname-extra: 
$pkgname-extra: Extra files for open-office(Math and Base).
EOF
	cd $startdir/src
	for file in *.rpm; do
		if `echo ${_toExtra[@]} | grep "${file}" 1>/dev/null 2>&1`
		then
			echo $file
			/usr/bin/rpm2targz $file
			tar xf $(basename "$file" .rpm).tar.gz -C $startdir/pkg2
		fi
	done
        cd $startdir/pkg2/opt
        mkdir -p $startdir/pkg2/usr/lib/openoffice.org${pkgver%.*}
        cp -r */* $startdir/pkg2/usr/lib/openoffice.org${pkgver%.*}
	mkdir -p $startdir/pkg2/usr/share/applications/
	mkdir -p $startdir/pkg2/usr/bin/
	cd $startdir/pkg/usr/bin/
	mv oo{base,math} $startdir/pkg2/usr/bin/
	mkdir -p $startdir/pkg2/usr/lib/openoffice.org${pkgver%.*}/share/xdg/
	mv $startdir/pkg/usr/lib/openoffice.org${pkgver%.*}/share/xdg/{base,math}.desktop $startdir/pkg2/usr/lib/openoffice.org${pkgver%.*}/share/xdg/
	mv $startdir/pkg/usr/share/applications/openoffice.org-${pkgver%.*}-{base,math}.desktop $startdir/pkg2/usr/share/applications/
	cd $startdir/pkg2/usr/lib/openoffice.org${pkgver%.*}/share/xdg/
	sed -i -e "s|openoffice.org$STRIMVER -base %U|oobase|g" base.desktop
	sed -i -e "s|openoffice.org$STRIMVER -math %U|oomath|g" math.desktop
	mkdir -p $startdir/pkg2/usr/lib/openoffice.org${pkgver%.*}/basis${pkgver%.*}/share/config/
	mv $startdir/pkg/usr/lib/openoffice.org${pkgver%.*}/basis${pkgver%.*}/share/config/{images.zip,images_crystal.zip,images_industrial.zip,images_classic.zip,images_hicontrast.zip} $startdir/pkg2/usr/lib/openoffice.org${pkgver%.*}/basis${pkgver%.*}/share/config/
	mkdir -p $startdir/pkg2/usr/lib/openoffice.org${pkgver%.*}/basis${pkgver%.*}/share/gallery/sounds
	mv $startdir/pkg/usr/lib/openoffice.org${pkgver%.*}/basis${pkgver%.*}/share/gallery/sounds $startdir/pkg2/usr/lib/openoffice.org${pkgver%.*}/basis${pkgver%.*}/share/gallery/sounds
	mkdir -p $startdir/pkg2/usr/lib/openoffice.org${pkgver%.*}/basis${pkgver%.*}/program/
	mv $startdir/pkg/usr/lib/openoffice.org${pkgver%.*}/basis${pkgver%.*}/program/classes $startdir/pkg2/usr/lib/openoffice.org${pkgver%.*}/basis${pkgver%.*}/program/classes/
	rm -rvf $startdir/pkg2/opt
	cd $startdir/pkg2
        /sbin/makepkg -l y -c n $startdir/$package2.txz
        cd $startdir
        md5sum $package2.txz > $startdir/$package2.md5
	#create dep file
	echo "${extradepends[@]} openoffice" | sed 's/ /\n/g' | sort -u | tr '\n' ','>$startdir/$package2.dep
	rm -rvf $startdir/pkg2
	unset package2
	cd $startdir/pkg/usr/bin/
	# patch to make OOo work with SCIM, as suggested by Ejis / Aymeric
	patch -p0 -i $startdir/src/openoffice.org3.scim.patch

	#fix symlinks problems
	cd $startdir/pkg/usr/lib
	ln -s libcrypto.so libcrypto.so.4
	ln -s libkdeui.so libkdeui.so.4
	ln -s libkdecore.so libkdecore.so.4
	ln -s libkabc.so libkabc.so.1
	ln -s libkio.so libkio.so.4
} 

create_slackdesc() {
mkdir $startdir/pkg/install
cat <<"EODESC" >$startdir/pkg/install/slack-desc
openoffice: openoffice (OpenOffice.org Office Suite)
openoffice: 
openoffice: OpenOffice.org the product is a multi-platform office productivity
openoffice: suite. It includes the key desktop applications, such as a word
openoffice: processor, spreadsheet, presentation manager, and drawing program,
openoffice: with a user interface and feature set similar to other office suites.
openoffice: Sophisticated and flexible, OpenOffice.org also works transparently
openoffice: with a variety of file formats, including those of Microsoft Office.
openoffice: 
openoffice: 
openoffice: 
EODESC
}

setup_doinst() {
cat <<"EODOINST" >>$startdir/pkg/install/doinst.sh
doinst() {
# update the mime desktop database
if [ -x usr/bin/update-desktop-database ]; then
        usr/bin/update-desktop-database -q
fi
# update the mime database
if [ -x usr/bin/update-mime-database ]; then
        usr/bin/update-mime-database usr/share/mime > /dev/null 2>&1
fi
}
doinst
EODOINST
}
detect_dependencies() {
	echo "Detecting dependencies..."
	depends=""
	
	depstring=$depends,atk,avahi,cxxlibs,dbus,dbus-glib,e2fsprogs,expat,fontconfig,freetype,gcc,gconf,glib2,glitz,gnome-vfs,gst-plugins-base,gstreamer,gtk+2,icu,libICE,libSM,libX11,libXau,libXaw,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,libXfixes,libXft,libXi,libXinerama,libXmu,libXpm,libXrandr,libXrender,libXt,libXtst,libXxf86vm,libdrm,libpng,libxcb,libxml2,mesa,net-tools,openssl,orbit2,pango,perl,pixman,python,qt-base,xcb-util,zlib
	unset FIRST
	for deps in $(echo "${depstring}" | sed 's/,/\n/g' | sort -u); do
		if [[ ! "$FIRST" ]]; then
			finaldeps=$deps,
			FIRST='1'
			continue
		fi
		finaldeps=${finaldeps}${deps},
	done
	echo "$finaldeps" | sed -e 's/^,//' -e 's/,$//' > $startdir/$package.dep
}
create_source_file(){
	[ -f $package.src ] && rm $package.src
	if [ ! -z $sourcetemplate ]; then
		echo $sourcetemplate/ZENBUILD >> $package.src
		echo $sourcetemplate/build-$pkgname.sh >> $package.src
	else
		echo ZENBUILD >> $package.src
		echo build-$pkgname.sh >> $package.src
	fi
	for SOURCES in ${source[@]}; do
		protocol=$(echo $SOURCES | sed 's|:.*||')
		if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
			if [ ! -z $sourcetemplate ]; then
				echo $sourcetemplate/$(basename $SOURCES) >> $package.src
			else
				echo $(basename $SOURCES) >> $package.src
			fi
		else
			echo $SOURCES >> $package.src
		fi
	done
}
post_checks(){
	# Ideas taken from src2pkg :)
	if [ -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
		for DIRS in usr/doc/$pkgname-$pkgver usr/doc; do
			cd $startdir/pkg/$DIRS
			if [[ $(find . -type f) = "" ]] ; then
				cd ..
				rmdir $DIRS
			fi
		done
	fi
	# if the docs weren't deleted ...
	if [ -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
		cd $startdir/pkg/usr/doc/$pkgname-$pkgver
		#remove zero lenght files
		if [[ $(find . -type f -size 0) ]]; then
			echo "Removing some zero lenght files"
			find . -type f -size 0 -exec rm -f {} \;
		fi
	fi
	# check if we need to add code to handle info pages
	if [[ -d $startdir/pkg/usr/info ]] && [[ ! $(grep install-info $startdir/pkg/install/doinst.sh &> /dev/null) ]] ; then
		echo "Found info files - Adding install-info command to doinst.sh"
		INFO_LIST=$(ls -1 $startdir/pkg/usr/info)
		echo "" >> $startdir/pkg/install/doinst.sh
		echo "if [ -x usr/bin/install-info ] ; then" >> $startdir/pkg/install/doinst.sh
		for page in $(echo $INFO_LIST) ; do
			echo " usr/bin/install-info --info-dir=usr/info usr/info/$page 2>/dev/null" >> $startdir/pkg/install/doinst.sh
		done
		echo "fi" >> $startdir/pkg/install/doinst.sh
	fi
	[[ -e $startdir/pkg/usr/info/dir ]] && rm -f $startdir/pkg/usr/info/dir

	if [ -d $startdir/pkg/etc ]; then
		cd $startdir/pkg/
		for conf in $(find ./etc -type f) ; do
			conf=${conf: 2}
			dotnew=( "${dotnew[@]}" "$conf" )
		done
	fi
	if [[ "$dotnew" ]]; then
        for files in ${dotnew[@]} ; do
                fullfile="${startdir}/pkg/${files}"
                if [ -e "$fullfile" ]; then
                        mv $fullfile ${fullfile}.new
                else
                        echo "$fullfile was not found"
                        exit 2
                fi
        done
        cat<<"EODOTNEW" >>$startdir/pkg/install/doinst.sh
#Added by buildpkg 1.7.0
dotnew() {
        NEW="${1}.new"
        OLD="$1"
        if [ ! -e $OLD ]; then
                mv $NEW $OLD
        elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
                rm $NEW
        fi
}
EODOTNEW
for i in ${dotnew[@]}; do
echo "dotnew $i" >> $startdir/pkg/install/doinst.sh
done
fi
}

PKGEXTENSION=txz

####End Non Redundant Code############################

#Variables

startdir=$(pwd)
SRC=$startdir/src
PKG=$startdir/pkg

pkgname=openoffice
pkgver=3.2.0
pkgrel=1
zenver=64
arch=i586
package=$pkgname-$pkgver-$arch-$zenver.$pkgrel
_minorver=9483
_toExtra=(ooobasis${pkgver%.*}-base-$pkgver-$_minorver.i586.rpm ooobasis${pkgver%.*}-en-US-math-$pkgver-$_minorver.i586.rpm openoffice.org3-math-$pkgver-$_minorver.i586.rpm ooobasis${pkgver%.*}-en-US-base-$pkgver-$_minorver.i586.rpm openoffice.org3-base-$pkgver-$_minorver.i586.rpm ooobasis${pkgver%.*}-math-$pkgver-$_minorver.i586.rpm ooobasis${pkgver%.*}-ooofonts-$pkgver-$_minorver.i586.rpm)
_startDir=http://go-oo.mirrorbrain.org/stable/linux-i586/${pkgver%.*}
source=("http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-images-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-base-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-binfilter-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-calc-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-core01-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-core02-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-core03-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-core04-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-core05-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-core06-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-core07-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-draw-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-en-US-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-en-US-base-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-en-US-binfilter-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-en-US-calc-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-en-US-draw-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-en-US-impress-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-en-US-math-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-en-US-res-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-en-US-writer-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-gnome-integration-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-graphicfilter-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-impress-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-javafilter-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-kde-integration-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-math-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-ooolinguistic-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-pyuno-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-testtool-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-writer-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-xsltfilter-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/openoffice.org-ure-1.6.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/openoffice.org3-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/openoffice.org3-base-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/openoffice.org3-calc-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/openoffice.org3-draw-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/openoffice.org3-en-US-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/openoffice.org3-impress-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/openoffice.org3-math-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/openoffice.org3-writer-3.2.0-9483.i586.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/openoffice.org3.2-freedesktop-menus-3.2-9483.noarch.rpm" "http://go-oo.mirrorbrain.org/stable/linux-i586/3.2/ooobasis3.2-ooofonts-3.2.0-9483.i586.rpm" "openoffice.org3.scim.patch" "http://pnboy.pinguix.com/my_packages/zenwalk/openoffice/3.2.0/openintro_go-oo.bmp" "http://pnboy.pinguix.com/my_packages/zenwalk/openoffice/3.2.0/openabout_go-oo.bmp")
sourcetemplate=http://pnboy.pinguix.com/my_packages/zenwalk/openoffice/3.2.0
docs=()
export CFLAGS="-O2 -march=i586 -mtune=i686"
export CXXFLAGS="-O2 -march=i586 -mtune=i686"

#Execution

check_for_root
clean_old_builds
prepare_directory
set_pre_permissions
build
if [ ! "$?" = "0" ]; then
	echo "build() failed."
	exit 2
fi
create_slackdesc
post_checks
setup_doinst
check_for_menu_compliance
strip_binaries
gzip_man_and_info_pages
set_post_permissions
copy_build_script
create_package
create_source_file
detect_dependencies
echo "Package has been built."
echo "Cleaning pkg and src directories"
clean_dirs
